import { messageHistory, recordMessage } from "./messages.js";
import { reply } from "./api.js";

export function setupSelections() {
    let selectedLocation = '';
    const chatInput = document.getElementById('chat-input');
    const chatMessages = document.getElementById('chat-messages');
    const chatInputContainer = document.getElementById('chat-input-container');

    const subjectSelector = document.createElement('div');
    subjectSelector.id = 'subject-selector';
    subjectSelector.className = 'flex-1 p-6 overflow-y-auto flex flex-col items-center justify-center hidden';
    subjectSelector.innerHTML = `
        <h3 class="text-lg font-medium text-gray-800 mb-4">Vă rugăm să selectați subiectul:</h3>
        <div class="flex flex-col space-y-4 w-full max-w-xs">
        <button id="licenta-btn" class="location-btn bg-gray-800 hover:bg-gray-700 text-white py-3 px-6 rounded-lg text-center">
        Admitere Licență 2025
        </button>
        </div>
        `;

    const locationSelector = document.getElementById('location-selector');
    locationSelector.parentNode.insertBefore(subjectSelector,
        locationSelector.nextSibling);

    function selectLocation(location) {
        selectedLocation = location;

        locationSelector.classList.add('hidden');
        subjectSelector.classList.remove('hidden');

        document.getElementById('licenta-btn').addEventListener('click', function() {
            selectSubject('Admitere Licență 2025');
        });
    }

    function selectSubject(subject) {
        const selectedSubject = subject;

        subjectSelector.classList.add('hidden');
        chatMessages.classList.remove('hidden');
        chatInputContainer.classList.remove('hidden');

        setTimeout(() => {
            reply(`Bună 👋! Ați selectat ${selectedLocation}, subiect: ${selectedSubject}. Cum vă pot ajuta cu informații despre admitere?<br><br>Răspunsurile sunt orientative și pot conține erori. Vă rugăm să verificați toate răspunsurile cu sursele furnizate. <br> Platforma oficială de admitere se găsește la adresa <a href="https://admitere.pub.ro" class="text-blue-600 underline hover:text-blue-800" target="_blank" rel="noopener noreferrer">admitere.pub.ro</a>.<br>Pentru orice întrebare suplimentară, puteți contacta <a href="mailto:admitere.anticipata@upb.ro" class="text-blue-600 underline hover:text-blue-800">admitere.anticipata@upb.ro</a>.<br>Pentru contact telefonic ne puteți găsi <a class="text-blue-600 underline hover:text-blue-800" href="https://admitere.pub.ro/docs/Date%20contact%20CLA_2025.pdf?v=24.03.29" target="_blank" rel="noopener noreferrer">aici</a>.`);
            recordMessage({ 
                role: "assistant", 
                content: `Bună! Ați selectat ${selectedLocation}, subiect: ${selectedSubject}. Cum vă pot ajuta cu informații despre admitere?`
            });

            // Also add the location and subject to the message history for context
            recordMessage({
                role: "system",
                content: `User has selected: ${selectedLocation}, Subject: ${selectedSubject}`
            });
        }, 500);

        // Focus the input
        chatInput.focus();
    }

    document.getElementById('bucuresti-btn').addEventListener('click', function() {
        selectLocation('Centrul Universitar București');
    });

    document.getElementById('pitesti-btn').addEventListener('click', function() {
        selectLocation('Centrul Universitar Pitești');
    });
}
